@@ -1,5 +1,7 @@
 /***************************************************************************
-* Copyright (c) 2016, Johan Mabille and Sylvain Corlay                     *
+* Copyright (c) Johan Mabille, Sylvain Corlay, Wolf Vollprecht and         *
+* Martin Renou                                                             *
+* Copyright (c) QuantStack                                                 *
 *                                                                          *
 * Distributed under the terms of the BSD 3-Clause License.                 *
 *                                                                          *
@@ -78,6 +80,7 @@ namespace xsimd
         static constexpr std::size_t size = 8;
         using batch_bool_type = batch_bool<int32_t, 8>;
         static constexpr std::size_t align = 32;
+        using storage_type = __m256i;
     };
 
     template <>
@@ -87,6 +90,7 @@ namespace xsimd
         static constexpr std::size_t size = 8;
         using batch_bool_type = batch_bool<uint32_t, 8>;
         static constexpr std::size_t align = 32;
+        using storage_type = __m256i;
     };
 
     template <>
@@ -101,8 +105,8 @@ namespace xsimd
         using base_type::store_aligned;
         using base_type::store_unaligned;
 
-        XSIMD_DECLARE_LOAD_STORE_INT32(int32_t, 8);
-        XSIMD_DECLARE_LOAD_STORE_LONG(int32_t, 8);
+        XSIMD_DECLARE_LOAD_STORE_INT32(int32_t, 8)
+        XSIMD_DECLARE_LOAD_STORE_LONG(int32_t, 8)
    };
 
     batch<int32_t, 8> operator<<(const batch<int32_t, 8>& lhs, int32_t rhs);
@@ -120,8 +124,8 @@ namespace xsimd
         using base_type::store_aligned;
         using base_type::store_unaligned;
 
-        XSIMD_DECLARE_LOAD_STORE_INT32(uint32_t, 8);
-        XSIMD_DECLARE_LOAD_STORE_LONG(uint32_t, 8);
+        XSIMD_DECLARE_LOAD_STORE_INT32(uint32_t, 8)
+        XSIMD_DECLARE_LOAD_STORE_LONG(uint32_t, 8)
     };
 
     batch<uint32_t, 8> operator<<(const batch<uint32_t, 8>& lhs, int32_t rhs);
@@ -133,24 +137,24 @@ namespace xsimd
 
     inline batch<int32_t, 8>& batch<int32_t, 8>::load_aligned(const float* src)
     {
-        m_value = _mm256_cvtps_epi32(_mm256_load_ps(src));
+        this->m_value = _mm256_cvtps_epi32(_mm256_load_ps(src));
         return *this;
     }
 
     inline batch<int32_t, 8>& batch<int32_t, 8>::load_unaligned(const float* src)
     {
-        m_value = _mm256_cvtps_epi32(_mm256_loadu_ps(src));
+        this->m_value = _mm256_cvtps_epi32(_mm256_loadu_ps(src));
         return *this;
     }
 
     inline void batch<int32_t, 8>::store_aligned(float* dst) const
     {
-        _mm256_store_ps(dst, _mm256_cvtepi32_ps(m_value));
+        _mm256_store_ps(dst, _mm256_cvtepi32_ps(this->m_value));
     }
 
     inline void batch<int32_t, 8>::store_unaligned(float* dst) const
     {
-        _mm256_storeu_ps(dst, _mm256_cvtepi32_ps(m_value));
+        _mm256_storeu_ps(dst, _mm256_cvtepi32_ps(this->m_value));
     }
 
     XSIMD_DEFINE_LOAD_STORE(int32_t, 8, int8_t, 32)
